==> jc-1.4.0.tar.gz: javax/security/sasl/SaslException.h <==
// public class javax.security.sasl.SaslException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a6a0dc46b22541cb javax_security_sasl_SaslException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_javax_security_sasl_SaslException_H_
#define _JC_javax_security_sasl_SaslException_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_security_sasl_SaslException$sub_refs	_jc_javax_security_sasl_SaslException$sub_refs;
typedef struct _jc_javax_security_sasl_SaslException$sub_nonrefs	_jc_javax_security_sasl_SaslException$sub_nonrefs;
typedef struct _jc_javax_security_sasl_SaslException$refs	_jc_javax_security_sasl_SaslException$refs;
typedef struct _jc_javax_security_sasl_SaslException$nonrefs	_jc_javax_security_sasl_SaslException$nonrefs;
typedef struct _jc_javax_security_sasl_SaslException$object	_jc_javax_security_sasl_SaslException$object;

typedef const struct _jc_javax_security_sasl_SaslException$vmethods	_jc_javax_security_sasl_SaslException$vmethods;
typedef const struct _jc_javax_security_sasl_SaslException$vtable	_jc_javax_security_sasl_SaslException$vtable;
typedef const struct _jc_javax_security_sasl_SaslException$vtype	_jc_javax_security_sasl_SaslException$vtype;

// Constructors
extern void _jc_javax_security_sasl_SaslException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
extern void _jc_javax_security_sasl_SaslException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_sasl_SaslException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_javax_security_sasl_SaslException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
extern void _jc_javax_security_sasl_SaslException$method$printStackTrace$0c533e6284fdc6db(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
extern void _jc_javax_security_sasl_SaslException$method$printStackTrace$0235c4ad6dac60e9(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintStream$object *);
extern void _jc_javax_security_sasl_SaslException$method$printStackTrace$a53e2b4b86a79644(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintWriter$object *);
extern void _jc_javax_security_sasl_SaslException$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_SaslException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$printStackTrace$0c533e6284fdc6db;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$printStackTrace$0235c4ad6dac60e9;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$printStackTrace$a53e2b4b86a79644;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_security_sasl_SaslException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
	void	(*printStackTrace$0c533e6284fdc6db)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
	void	(*printStackTrace$0235c4ad6dac60e9)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintStream$object *);
	void	(*printStackTrace$a53e2b4b86a79644)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintWriter$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *);
};

// Vtable
struct _jc_javax_security_sasl_SaslException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_security_sasl_SaslException$vmethods	javax_security_sasl_SaslException;
};

// Vtype
struct _jc_javax_security_sasl_SaslException$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_SaslException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_SaslException$sub_refs {
	struct _jc_java_lang_Throwable$object	*__5fexception;
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_SaslException$refs {
    _jc_javax_security_sasl_SaslException$sub_refs	javax_security_sasl_SaslException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_SaslException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_SaslException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_security_sasl_SaslException$sub_nonrefs	javax_security_sasl_SaslException;
};

// Object instance structure
struct _jc_javax_security_sasl_SaslException$object {
	_jc_javax_security_sasl_SaslException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_SaslException$vtype	*vtype;
	_jc_javax_security_sasl_SaslException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_SaslException$vtype _jc_javax_security_sasl_SaslException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_SaslException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_SaslException$class_object;

#endif	/* _JC_javax_security_sasl_SaslException_H_ */

==> jc-1.4.6.tar.gz: javax/security/sasl/SaslException.h <==
// public class javax.security.sasl.SaslException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a6a0dc46b22541cb javax_security_sasl_SaslException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_javax_security_sasl_SaslException_H_
#define _JC_javax_security_sasl_SaslException_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_security_sasl_SaslException$sub_refs	_jc_javax_security_sasl_SaslException$sub_refs;
typedef struct _jc_javax_security_sasl_SaslException$sub_nonrefs	_jc_javax_security_sasl_SaslException$sub_nonrefs;
typedef struct _jc_javax_security_sasl_SaslException$refs	_jc_javax_security_sasl_SaslException$refs;
typedef struct _jc_javax_security_sasl_SaslException$nonrefs	_jc_javax_security_sasl_SaslException$nonrefs;
typedef struct _jc_javax_security_sasl_SaslException$object	_jc_javax_security_sasl_SaslException$object;

typedef const struct _jc_javax_security_sasl_SaslException$vmethods	_jc_javax_security_sasl_SaslException$vmethods;
typedef const struct _jc_javax_security_sasl_SaslException$vtable	_jc_javax_security_sasl_SaslException$vtable;
typedef const struct _jc_javax_security_sasl_SaslException$vtype	_jc_javax_security_sasl_SaslException$vtype;

// Constructors
extern void _jc_javax_security_sasl_SaslException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_SaslException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_SaslException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_javax_security_sasl_SaslException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_SaslException$method$printStackTrace$0c533e6284fdc6db(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_SaslException$method$printStackTrace$0235c4ad6dac60e9(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_SaslException$method$printStackTrace$a53e2b4b86a79644(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_SaslException$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_sasl_SaslException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$printStackTrace$0c533e6284fdc6db;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$printStackTrace$0235c4ad6dac60e9;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$printStackTrace$a53e2b4b86a79644;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_javax_security_sasl_SaslException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_security_sasl_SaslException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$0c533e6284fdc6db)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$0235c4ad6dac60e9)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$a53e2b4b86a79644)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_security_sasl_SaslException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_sasl_SaslException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_security_sasl_SaslException$vmethods	javax_security_sasl_SaslException;
};

// Vtype
struct _jc_javax_security_sasl_SaslException$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_SaslException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_SaslException$sub_refs {
	struct _jc_java_lang_Throwable$object	*__5fexception;
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_SaslException$refs {
    _jc_javax_security_sasl_SaslException$sub_refs	javax_security_sasl_SaslException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_SaslException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_SaslException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_security_sasl_SaslException$sub_nonrefs	javax_security_sasl_SaslException;
};

// Object instance structure
struct _jc_javax_security_sasl_SaslException$object {
	_jc_javax_security_sasl_SaslException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_SaslException$vtype	*vtype;
	_jc_javax_security_sasl_SaslException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_SaslException$vtype _jc_javax_security_sasl_SaslException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_SaslException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_SaslException$class_object;

#endif	/* _JC_javax_security_sasl_SaslException_H_ */
